@@ -150,6 +150,12 @@ class URLMapTest(TestCase):
             ValidationError, self.url.save,
             {'content_map': ['Status code requires a content map']})
 
+    def test_save_data_invalid_for_field_definition_raises(self):
+        self.url.path = 'x' * 2001
+        self.url.status_code = 404
+        m = 'Ensure this value has at most 2000 characters (it has 2001).'
+        self.assertRaisesMessage(ValidationError, self.url.save, {'path': [m]})
+
     def test_delete_deletes_cache(self):
         self.site.save()
         self.url.site = self.site
@@ -314,24 +320,26 @@ class RouteTest(TestCase):
 
     def test_content_map_class_based_view(self):
         content_map = models.ContentMap(
-            view='django.views.generic.base.TemplateView')
+            view='urlographer.test_views.SampleClassView')
         content_map.options['initkwargs'] = {
-            'template_name': 'admin/base.html'}
+            'test_val': 'testing 1 2 3'}
         content_map.save()
         models.URLMap.objects.create(
             site=self.site, path='/test', content_map=content_map)
         response = views.route(self.factory.get('/test'))
         self.assertEqual(response.status_code, 200)
+        self.assertEqual(response.content, 'test value=testing 1 2 3')
 
     def test_content_map_view_function(self):
         content_map = models.ContentMap(
-            view='django.views.generic.simple.direct_to_template')
-        content_map.options['template'] = 'admin/base.html'
+            view='urlographer.test_views.sample_view')
+        content_map.options['test_val'] = 'testing 1 2 3'
         content_map.save()
         models.URLMap.objects.create(
             site=self.site, path='/test', content_map=content_map)
         response = views.route(self.factory.get('/test'))
         self.assertEqual(response.status_code, 200)
+        self.assertEqual(response.content, 'test value=testing 1 2 3')
 
     def test_force_cache_invalidation(self):
         path = '/test'
@@ -465,3 +473,26 @@ class ForceCacheInvalidationTest(TestCase):
              'REMOTE_ADDR': '10.0.0.2'})
         request.user = any_user(is_superuser=True)
         self.assertTrue(utils.force_cache_invalidation(request))
+
+
+class SitemapTest(TestCase):
+    def setUp(self):
+        self.factory = RequestFactory()
+        self.mox = mox.Mox()
+
+    def tearDown(self):
+        self.mox.UnsetStubs()
+
+    def test_get(self):
+        request = self.factory.get('/sitemap.xml') 
+        self.mox.StubOutWithMock(views.URLMap.objects, 'filter')
+        self.mox.StubOutWithMock(views, 'contrib_sitemap')
+        self.mox.StubOutWithMock(views, 'GenericSitemap')
+        views.URLMap.objects.filter(
+            status_code=200, on_sitemap=True).AndReturn('mock queryset')
+        views.GenericSitemap({'queryset': 'mock queryset'}).AndReturn(
+            'mock GenericSitemap')
+        views.contrib_sitemap(request, {'urlmap': 'mock GenericSitemap'})
+        self.mox.ReplayAll()
+        views.sitemap(request)
+        self.mox.VerifyAll()
